@@ -5,7 +5,7 @@ use base qw/Catalyst::Controller::HTML::FormFu Catalyst::Controller::BindLex/;
 
 use Digest::MD5 qw/md5_hex/;
 use Data::FormValidator::Constraints::DateTime qw(:all);
-use Crypt::PassGen;
+use Text::Password::Pronounceable;
 
 my $auth_class = MojoMojo->config->{auth_class};
 
@@ -32,7 +32,7 @@ Log in through the authentication system.
 sub login : Global {
     my ($self,$c) = @_;
     my $message:Stashed;
-    $message ||= 'please enter username &amp; password';
+    $message ||= 'Please enter username &amp; password';
     if ( $c->req->params->{login} ) {
          if ( $c->authenticate( { login => $c->req->params->{'login'}, 
                                   pass => $c->req->params->{'pass'} } ) ) {
@@ -43,7 +43,7 @@ sub login : Global {
             return;
         }
         else {
-            $c->stash->{message} = 'could not authenticate that login.';
+            $c->stash->{message} = 'Could not authenticate that login.';
         }
     }
     $c->stash->{template} ||= "user/login.tt";
@@ -138,7 +138,7 @@ sub password : Path('/prefs/password') {
       $c->stash->{user}->update();
       $c->stash->{message}='Your password has been updated';
     }
-    $c->stash->{message} ||= 'please fill out all fields';
+    $c->stash->{message} ||= 'Please fill out all fields!';
 }
 
 sub recover_pass : Global {
@@ -151,8 +151,9 @@ sub recover_pass : Global {
 	$c->flash->{message}='Could not recover password.';
 	return $c->res->redirect($c->uri_for('login'));
     }
-    my $password:Stashed;
-    ($password)=Crypt::PassGen::passgen(NLETT=>6,NWORDS=>1);
+    my $password : Stashed = '';
+    ($password)=Text::Password::Pronounceable->generate(6, 10);
+    my $message:Stashed='';
     if ($c->email(
         header => [
             From    => $c->config->{system_mail},
@@ -163,9 +164,9 @@ sub recover_pass : Global {
     )){
         $user->pass($password);
         $user->update();
-        my $message:Stashed='Emailed you your new password.';
+        $message = 'Emailed you your new password.';
     } else {
-        my $message:Stashed='Error occurred while emailing you your new password.';
+        $message = 'Error occurred while emailing you your new password.';
     }
     $c->forward('login');
 }
@@ -196,7 +197,7 @@ sub register : Global FormConfig {
 
     $user->fill_formfu_values($form);
     if ( $form->submitted && !$form->has_errors ) {
-         $user->active(0);
+         $user->active(-1);
          $user->populate_from_formfu( $form );
          $user->insert();
          $c->forward('do_register',[$user]);
@@ -254,6 +255,30 @@ sub validate : Global {
     }
     $c->stash->{template}='user/validate.tt';
 }
+=item reconfirm
+
+Send the confirmation mail again to another address.
+
+=cut
+
+sub reconfirm : Local {
+    my ($self,$c) = @_;
+    $c->detach('/default') unless $c->req->method eq 'POST'; 
+    if ($c->user->obj->email ne $c->req->param('email')) {
+        if( $c->model('DBIC::Person')
+            ->search({email=>$c->req->param('email')})->count) {
+	        return $c->stash->{error}='That mail is already in use';
+        }
+    }
+    my $user=$c->user->obj;
+    $user->email($c->req->params->{email});
+    $user->active(-1);
+    $user->update();
+    $c->forward('do_register',[$user]);
+    $c->flash->{message}='confirmation message resent';
+    $c->res->redirect($c->uri_for('/'));
+}
+
 
 =item profile .profile
 
